require 'auth_proxy/version'
require 'rack'
require 'rack/reverse_proxy'
require 'rack/router'
require 'auth_proxy/callback'
require 'auth_proxy/proxy'
require 'auth_proxy/validator'

class AuthProxy
  include AuthProxy::Validator

  def initialize(auth_options={}, host_options={})
    @auth_options = auth_options

    @app = Rack::Router.new do
      get "/auth/github/callback" => AuthProxy::Callback.new(auth_options)
      host_options.keys.each do |path|
        get path + '/*' => AuthProxy::Proxy.new(host_options)
      end
    end
  end

  def call(env)
    @env = env
    return authenticate unless authenticated?
    @app.call(env)
  end

  private

  attr_reader :env, :auth_options

  def secret_cookie
    auth_options.fetch(:secret, 'change_me')
  end

  def authenticate
    [ 301, {"Location" => rack_request.base_url + '/auth/github'}, [] ]
  end
end
